@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use vars    qw[@ISA $STATUS $VERSION];
 use base    'CPANPLUS::Dist::Base';
-$VERSION = "0.9156";
+$VERSION = "0.9172";
 
 use CPANPLUS::Internals::Constants;
 use CPANPLUS::Internals::Constants::Report;
@@ -171,7 +171,7 @@ sub init {
     my $status  = $dist->status;
 
     $status->mk_accessors(qw[makefile make test created installed uninstalled
-                             bin_make _prepare_args _create_args _install_args]
+                             bin_make _prepare_args _create_args _install_args _metadata]
                         );
 
     return 1;
@@ -291,7 +291,12 @@ sub prepare {
             ### end of prereq resolving ###
         }
 
+        my $metadata = $dist->status->_metadata;
+        my $x_use_unsafe_inc = ( defined $metadata && exists $metadata->{x_use_unsafe_inc} ? $metadata->{x_use_unsafe_inc} : undef );
+        $x_use_unsafe_inc = 1 unless defined $x_use_unsafe_inc;
 
+        local $ENV{PERL_USE_UNSAFE_INC} = $x_use_unsafe_inc
+          unless exists $ENV{PERL_USE_UNSAFE_INC};
 
         ### don't run 'perl makefile.pl' again if there's a makefile already
         if( -e MAKEFILE->() && (-M MAKEFILE->() < -M $dir) && !$force ) {
@@ -355,7 +360,7 @@ sub prepare {
             ### in @INC, stopping us from resolving dependencies on CPANPLUS
             ### at bootstrap time properly.
 
-            my @run_perl    = ( '-e', PERL_WRAPPER );
+            my @run_perl    = ( '-MCPANPLUS::Internals::Utils::Autoflush' );
             my $cmd         = [$perl, @run_perl, $makefile_pl, @mmflags];
 
             ### set ENV var to tell underlying code this is what we're
@@ -610,6 +615,14 @@ sub create {
     my $fail; my $prereq_fail; my $test_fail;
     my $status = { };
     RUN: {
+
+        my $metadata = $dist->status->_metadata;
+        my $x_use_unsafe_inc = ( defined $metadata && exists $metadata->{x_use_unsafe_inc} ? $metadata->{x_use_unsafe_inc} : undef );
+        $x_use_unsafe_inc = 1 unless defined $x_use_unsafe_inc;
+
+        local $ENV{PERL_USE_UNSAFE_INC} = $x_use_unsafe_inc
+          unless exists $ENV{PERL_USE_UNSAFE_INC};
+
         ### this will set the directory back to the start
         ### dir, so we must chdir /again/
         my $ok = $dist->_resolve_prereqs(
@@ -832,6 +845,13 @@ sub install {
 
     my $fail; my $captured;
 
+    my $metadata = $dist->status->_metadata;
+    my $x_use_unsafe_inc = ( defined $metadata && exists $metadata->{x_use_unsafe_inc} ? $metadata->{x_use_unsafe_inc} : undef );
+    $x_use_unsafe_inc = 1 unless defined $x_use_unsafe_inc;
+
+    local $ENV{PERL_USE_UNSAFE_INC} = $x_use_unsafe_inc
+      unless exists $ENV{PERL_USE_UNSAFE_INC};
+
     ### 'make install' section ###
     ### XXX need makeflags here too?
     ### yes, but they should really be split out.. see bug #4143
